@@ -118,7 +118,12 @@ impl MarkdownlintConfig {
                 let toml_value = toml_value.map(normalize_toml_table_keys);
                 let rule_config = sourced_config.rules.entry(norm_rule_key.clone()).or_default();
                 if let Some(tv) = toml_value {
-                    if let toml::Value::Table(table) = tv {
+                    if let toml::Value::Table(mut table) = tv {
+                        // Special handling for MD007: Add style = "fixed" for markdownlint compatibility
+                        if norm_rule_key == "MD007" && !table.contains_key("style") {
+                            table.insert("style".to_string(), toml::Value::String("fixed".to_string()));
+                        }
+
                         for (k, v) in table {
                             let norm_config_key = k; // Already normalized
                             rule_config
@@ -169,6 +174,23 @@ impl MarkdownlintConfig {
                                     line: None,
                                 }],
                             });
+
+                        // Special handling for MD007: Add style = "fixed" for markdownlint compatibility
+                        if norm_rule_key == "MD007" && !rule_config.values.contains_key("style") {
+                            rule_config.values.insert(
+                                "style".to_string(),
+                                SourcedValue {
+                                    value: toml::Value::String("fixed".to_string()),
+                                    source: ConfigSource::Markdownlint,
+                                    overrides: vec![crate::config::ConfigOverride {
+                                        value: toml::Value::String("fixed".to_string()),
+                                        source: ConfigSource::Markdownlint,
+                                        file: file.clone(),
+                                        line: None,
+                                    }],
+                                },
+                            );
+                        }
                     }
                 } else {
                     log::error!(
@@ -191,6 +213,11 @@ impl MarkdownlintConfig {
     ) -> crate::config::SourcedConfigFragment {
         let mut fragment = crate::config::SourcedConfigFragment::default();
         let file = file_path.map(|s| s.to_string());
+
+        // Accumulate disabled and enabled rules
+        let mut disabled_rules = Vec::new();
+        let mut enabled_rules = Vec::new();
+
         for (key, value) in &self.0 {
             // Special handling for line-length as a global setting
             if key.eq_ignore_ascii_case("line-length") || key.eq_ignore_ascii_case("line_length") {
@@ -211,21 +238,11 @@ impl MarkdownlintConfig {
                 // Special handling for boolean values (true/false)
                 if value.is_bool() {
                     if !value.as_bool().unwrap_or(false) {
-                        // Add to global.disable
-                        fragment.global.disable.push_override(
-                            vec![norm_rule_key.clone()],
-                            crate::config::ConfigSource::Markdownlint,
-                            file.clone(),
-                            None,
-                        );
+                        // Accumulate disabled rules
+                        disabled_rules.push(norm_rule_key.clone());
                     } else {
-                        // Add to global.enable (if true)
-                        fragment.global.enable.push_override(
-                            vec![norm_rule_key.clone()],
-                            crate::config::ConfigSource::Markdownlint,
-                            file.clone(),
-                            None,
-                        );
+                        // Accumulate enabled rules
+                        enabled_rules.push(norm_rule_key.clone());
                     }
                     continue;
                 }
@@ -233,7 +250,12 @@ impl MarkdownlintConfig {
                 let toml_value = toml_value.map(normalize_toml_table_keys);
                 let rule_config = fragment.rules.entry(norm_rule_key.clone()).or_default();
                 if let Some(tv) = toml_value {
-                    if let toml::Value::Table(table) = tv {
+                    if let toml::Value::Table(mut table) = tv {
+                        // Special handling for MD007: Add style = "fixed" for markdownlint compatibility
+                        if norm_rule_key == "MD007" && !table.contains_key("style") {
+                            table.insert("style".to_string(), toml::Value::String("fixed".to_string()));
+                        }
+
                         for (rk, rv) in table {
                             let norm_rk = crate::config::normalize_key(&rk);
                             let sv = rule_config.values.entry(norm_rk.clone()).or_insert_with(|| {
@@ -265,10 +287,48 @@ impl MarkdownlintConfig {
                                     line: None,
                                 }],
                             });
+
+                        // Special handling for MD007: Add style = "fixed" for markdownlint compatibility
+                        if norm_rule_key == "MD007" && !rule_config.values.contains_key("style") {
+                            rule_config.values.insert(
+                                "style".to_string(),
+                                crate::config::SourcedValue {
+                                    value: toml::Value::String("fixed".to_string()),
+                                    source: crate::config::ConfigSource::Markdownlint,
+                                    overrides: vec![crate::config::ConfigOverride {
+                                        value: toml::Value::String("fixed".to_string()),
+                                        source: crate::config::ConfigSource::Markdownlint,
+                                        file: file.clone(),
+                                        line: None,
+                                    }],
+                                },
+                            );
+                        }
                     }
                 }
             }
         }
+
+        // Set all disabled rules at once
+        if !disabled_rules.is_empty() {
+            fragment.global.disable.push_override(
+                disabled_rules,
+                crate::config::ConfigSource::Markdownlint,
+                file.clone(),
+                None,
+            );
+        }
+
+        // Set all enabled rules at once
+        if !enabled_rules.is_empty() {
+            fragment.global.enable.push_override(
+                enabled_rules,
+                crate::config::ConfigSource::Markdownlint,
+                file.clone(),
+                None,
+            );
+        }
+
         if let Some(_f) = file {
             // SourcedConfigFragment does not have loaded_files, so skip
         }
