@@ -81,6 +81,17 @@ pub enum RuleCategory {
     Other,
 }
 
+/// Capability of a rule to fix issues
+#[derive(Debug, Clone, Copy, PartialEq, Eq)]
+pub enum FixCapability {
+    /// Rule can automatically fix all violations it detects
+    FullyFixable,
+    /// Rule can fix some violations based on context
+    ConditionallyFixable,
+    /// Rule cannot fix violations (by design)
+    Unfixable,
+}
+
 /// Remove marker /// TRAIT_MARKER_V1
 pub trait Rule: DynClone + Send + Sync {
     fn name(&self) -> &'static str;
@@ -148,6 +159,17 @@ pub trait Rule: DynClone + Send + Sync {
         None
     }
 
+    /// Returns config key aliases for this rule
+    /// This allows rules to accept alternative config key names for backwards compatibility
+    fn config_aliases(&self) -> Option<std::collections::HashMap<String, String>> {
+        None
+    }
+
+    /// Declares the fix capability of this rule
+    fn fix_capability(&self) -> FixCapability {
+        FixCapability::FullyFixable // Safe default for backward compatibility
+    }
+
     /// Factory: create a rule from config (if present), or use defaults.
     fn from_config(_config: &crate::config::Config) -> Box<dyn Rule>
     where
@@ -198,19 +220,19 @@ pub fn is_rule_disabled_at_line(content: &str, rule_name: &str, line_num: usize)
         let line = line.trim();
 
         // Check for disable comments (both global and rule-specific)
-        if let Some(rules) = parse_disable_comment(line) {
-            if rules.is_empty() || rules.contains(&rule_name) {
-                is_disabled = true;
-                continue;
-            }
+        if let Some(rules) = parse_disable_comment(line)
+            && (rules.is_empty() || rules.contains(&rule_name))
+        {
+            is_disabled = true;
+            continue;
         }
 
         // Check for enable comments (both global and rule-specific)
-        if let Some(rules) = parse_enable_comment(line) {
-            if rules.is_empty() || rules.contains(&rule_name) {
-                is_disabled = false;
-                continue;
-            }
+        if let Some(rules) = parse_enable_comment(line)
+            && (rules.is_empty() || rules.contains(&rule_name))
+        {
+            is_disabled = false;
+            continue;
         }
     }
 
@@ -628,7 +650,7 @@ MD001 should still be enabled here"#;
 
     <!-- rumdl-disable MD001 -->
     This is in an indented code block
-    
+
 MD001 should still be enabled here"#;
 
         assert!(!is_rule_disabled_at_line(indented_content, "MD001", 5));
