@@ -260,7 +260,7 @@ impl HeadingUtils {
                         '-'
                     };
                     let visible_length = text_content.chars().count();
-                    let underline_length = visible_length.max(3); // Ensure at least 3 underline chars
+                    let underline_length = visible_length.max(1); // Ensure at least 1 underline char
                     format!(
                         "{}{}\n{}{}",
                         indentation,
@@ -279,7 +279,7 @@ impl HeadingUtils {
                     // Use Setext for h1/h2
                     let underline_char = if level == 1 { '=' } else { '-' };
                     let visible_length = text_content.chars().count();
-                    let underline_length = visible_length.max(3);
+                    let underline_length = visible_length.max(1);
                     format!(
                         "{}{}\n{}{}",
                         indentation,
@@ -297,7 +297,7 @@ impl HeadingUtils {
                     // Use Setext for h1/h2
                     let underline_char = if level == 1 { '=' } else { '-' };
                     let visible_length = text_content.chars().count();
-                    let underline_length = visible_length.max(3);
+                    let underline_length = visible_length.max(1);
                     format!(
                         "{}{}\n{}{}",
                         indentation,
@@ -603,9 +603,10 @@ pub fn remove_trailing_hashes(text: &str) -> String {
         {
             // Find the start of the trailing hash sequence
             let mut first_hash_index = last_hash_index;
+            let trimmed_chars: Vec<char> = trimmed.chars().collect();
             while first_hash_index > 0 {
                 let prev_index = first_hash_index - 1;
-                if trimmed.chars().nth(prev_index) == Some('#') {
+                if prev_index < trimmed_chars.len() && trimmed_chars[prev_index] == '#' {
                     first_hash_index = prev_index;
                 } else {
                     break;
@@ -824,7 +825,7 @@ mod tests {
         // Very short text for setext
         assert_eq!(
             HeadingUtils::convert_heading_style("Hi", 1, HeadingStyle::Setext1),
-            "Hi\n==="
+            "Hi\n=="
         );
     }
 
