@@ -118,71 +118,68 @@ impl Rule for MD004UnorderedListStyle {
 
         // Use centralized list blocks for better performance and accuracy
         for list_block in &ctx.list_blocks {
-            // Skip ordered lists
-            if list_block.is_ordered {
-                continue;
-            }
-
             // Check each list item in this block
+            // We need to check individual items even in mixed lists (ordered with nested unordered)
             for &item_line in &list_block.item_lines {
-                if let Some(line_info) = ctx.line_info(item_line) {
-                    if let Some(list_item) = &line_info.list_item {
-                        // Skip ordered lists (safety check)
-                        if list_item.is_ordered {
-                            continue;
-                        }
+                if let Some(line_info) = ctx.line_info(item_line)
+                    && let Some(list_item) = &line_info.list_item
+                {
+                    // Skip ordered list items - we only care about unordered ones
+                    if list_item.is_ordered {
+                        continue;
+                    }
 
-                        // Get the marker character
-                        let marker = list_item.marker.chars().next().unwrap();
+                    // Get the marker character
+                    let marker = list_item.marker.chars().next().unwrap();
 
-                        // Calculate offset for the marker position
-                        let offset = line_info.byte_offset + list_item.marker_column;
+                    // Calculate offset for the marker position
+                    let offset = line_info.byte_offset + list_item.marker_column;
 
-                        match self.config.style {
-                            UnorderedListStyle::Consistent => {
-                                // For consistent mode, we check consistency across the entire document
-                                if let Some(first) = first_marker {
-                                    // Check if current marker matches the first marker found
-                                    if marker != first {
-                                        let (line, col) = ctx.offset_to_line_col(offset);
-                                        warnings.push(LintWarning {
-                                            line,
-                                            column: col,
-                                            end_line: line,
-                                            end_column: col + 1,
-                                            message: format!(
-                                                "List marker '{marker}' does not match expected style '{first}'"
-                                            ),
-                                            severity: Severity::Warning,
-                                            rule_name: Some(self.name()),
-                                            fix: Some(Fix {
-                                                range: offset..offset + 1,
-                                                replacement: first.to_string(),
-                                            }),
-                                        });
-                                    }
-                                } else {
-                                    // This is the first marker we've found - set the style
-                                    first_marker = Some(marker);
-                                }
-                            }
-                            UnorderedListStyle::Sublist => {
-                                // Calculate expected marker based on indentation level
-                                // Each 2 spaces of indentation represents a nesting level
-                                let nesting_level = list_item.marker_column / 2;
-                                let expected_marker = match nesting_level % 3 {
-                                    0 => '*',
-                                    1 => '+',
-                                    2 => '-',
-                                    _ => {
-                                        // This should never happen as % 3 only returns 0, 1, or 2
-                                        // but fallback to asterisk for safety
-                                        '*'
-                                    }
-                                };
-                                if marker != expected_marker {
+                    match self.config.style {
+                        UnorderedListStyle::Consistent => {
+                            // For consistent mode, we check consistency across the entire document
+                            if let Some(first) = first_marker {
+                                // Check if current marker matches the first marker found
+                                if marker != first {
                                     let (line, col) = ctx.offset_to_line_col(offset);
                                     warnings.push(LintWarning {
+                                        line,
+                                        column: col,
+                                        end_line: line,
+                                        end_column: col + 1,
+                                        message: format!(
+                                            "List marker '{marker}' does not match expected style '{first}'"
+                                        ),
+                                        severity: Severity::Warning,
+                                        rule_name: Some(self.name()),
+                                        fix: Some(Fix {
+                                            range: offset..offset + 1,
+                                            replacement: first.to_string(),
+                                        }),
+                                    });
+                                }
+                            } else {
+                                // This is the first marker we've found - set the style
+                                first_marker = Some(marker);
+                            }
+                        }
+                        UnorderedListStyle::Sublist => {
+                            // Calculate expected marker based on indentation level
+                            // Each 2 spaces of indentation represents a nesting level
+                            let nesting_level = list_item.marker_column / 2;
+                            let expected_marker = match nesting_level % 3 {
+                                0 => '*',
+                                1 => '+',
+                                2 => '-',
+                                _ => {
+                                    // This should never happen as % 3 only returns 0, 1, or 2
+                                    // but fallback to asterisk for safety
+                                    '*'
+                                }
+                            };
+                            if marker != expected_marker {
+                                let (line, col) = ctx.offset_to_line_col(offset);
+                                warnings.push(LintWarning {
                                         line,
                                         column: col,
                                         end_line: line,
@@ -197,38 +194,37 @@ impl Rule for MD004UnorderedListStyle {
                                             replacement: expected_marker.to_string(),
                                         }),
                                     });
-                                }
                             }
-                            _ => {
-                                // Handle specific style requirements (asterisk, dash, plus)
-                                let target_marker = match self.config.style {
-                                    UnorderedListStyle::Asterisk => '*',
-                                    UnorderedListStyle::Dash => '-',
-                                    UnorderedListStyle::Plus => '+',
-                                    UnorderedListStyle::Consistent | UnorderedListStyle::Sublist => {
-                                        // These cases are handled separately above
-                                        // but fallback to asterisk for safety
-                                        '*'
-                                    }
-                                };
-                                if marker != target_marker {
-                                    let (line, col) = ctx.offset_to_line_col(offset);
-                                    warnings.push(LintWarning {
-                                        line,
-                                        column: col,
-                                        end_line: line,
-                                        end_column: col + 1,
-                                        message: format!(
-                                            "List marker '{marker}' does not match expected style '{target_marker}'"
-                                        ),
-                                        severity: Severity::Warning,
-                                        rule_name: Some(self.name()),
-                                        fix: Some(Fix {
-                                            range: offset..offset + 1,
-                                            replacement: target_marker.to_string(),
-                                        }),
-                                    });
+                        }
+                        _ => {
+                            // Handle specific style requirements (asterisk, dash, plus)
+                            let target_marker = match self.config.style {
+                                UnorderedListStyle::Asterisk => '*',
+                                UnorderedListStyle::Dash => '-',
+                                UnorderedListStyle::Plus => '+',
+                                UnorderedListStyle::Consistent | UnorderedListStyle::Sublist => {
+                                    // These cases are handled separately above
+                                    // but fallback to asterisk for safety
+                                    '*'
                                 }
+                            };
+                            if marker != target_marker {
+                                let (line, col) = ctx.offset_to_line_col(offset);
+                                warnings.push(LintWarning {
+                                    line,
+                                    column: col,
+                                    end_line: line,
+                                    end_column: col + 1,
+                                    message: format!(
+                                        "List marker '{marker}' does not match expected style '{target_marker}'"
+                                    ),
+                                    severity: Severity::Warning,
+                                    rule_name: Some(self.name()),
+                                    fix: Some(Fix {
+                                        range: offset..offset + 1,
+                                        replacement: target_marker.to_string(),
+                                    }),
+                                });
                             }
                         }
                     }
@@ -245,68 +241,64 @@ impl Rule for MD004UnorderedListStyle {
 
         // Use centralized list blocks
         for list_block in &ctx.list_blocks {
-            // Skip ordered lists
-            if list_block.is_ordered {
-                continue;
-            }
-
             // Process each list item in this block
+            // We need to check individual items even in mixed lists
             for &item_line in &list_block.item_lines {
-                if let Some(line_info) = ctx.line_info(item_line) {
-                    if let Some(list_item) = &line_info.list_item {
-                        // Skip ordered lists (safety check)
-                        if list_item.is_ordered {
-                            continue;
+                if let Some(line_info) = ctx.line_info(item_line)
+                    && let Some(list_item) = &line_info.list_item
+                {
+                    // Skip ordered list items - we only care about unordered ones
+                    if list_item.is_ordered {
+                        continue;
+                    }
+
+                    let line_idx = item_line - 1;
+                    if line_idx >= lines.len() {
+                        continue;
+                    }
+
+                    let line = &lines[line_idx];
+                    let marker = list_item.marker.chars().next().unwrap();
+
+                    // Determine the target marker
+                    let target_marker = match self.config.style {
+                        UnorderedListStyle::Consistent => {
+                            if let Some(first) = first_marker {
+                                first
+                            } else {
+                                first_marker = Some(marker);
+                                marker
+                            }
                         }
-
-                        let line_idx = item_line - 1;
-                        if line_idx >= lines.len() {
-                            continue;
-                        }
-
-                        let line = &lines[line_idx];
-                        let marker = list_item.marker.chars().next().unwrap();
-
-                        // Determine the target marker
-                        let target_marker = match self.config.style {
-                            UnorderedListStyle::Consistent => {
-                                if let Some(first) = first_marker {
-                                    first
-                                } else {
-                                    first_marker = Some(marker);
-                                    marker
+                        UnorderedListStyle::Sublist => {
+                            // Calculate expected marker based on indentation level
+                            // Each 2 spaces of indentation represents a nesting level
+                            let nesting_level = list_item.marker_column / 2;
+                            match nesting_level % 3 {
+                                0 => '*',
+                                1 => '+',
+                                2 => '-',
+                                _ => {
+                                    // This should never happen as % 3 only returns 0, 1, or 2
+                                    // but fallback to asterisk for safety
+                                    '*'
                                 }
                             }
-                            UnorderedListStyle::Sublist => {
-                                // Calculate expected marker based on indentation level
-                                // Each 2 spaces of indentation represents a nesting level
-                                let nesting_level = list_item.marker_column / 2;
-                                match nesting_level % 3 {
-                                    0 => '*',
-                                    1 => '+',
-                                    2 => '-',
-                                    _ => {
-                                        // This should never happen as % 3 only returns 0, 1, or 2
-                                        // but fallback to asterisk for safety
-                                        '*'
-                                    }
-                                }
-                            }
-                            UnorderedListStyle::Asterisk => '*',
-                            UnorderedListStyle::Dash => '-',
-                            UnorderedListStyle::Plus => '+',
-                        };
+                        }
+                        UnorderedListStyle::Asterisk => '*',
+                        UnorderedListStyle::Dash => '-',
+                        UnorderedListStyle::Plus => '+',
+                    };
 
-                        // Replace the marker if needed
-                        if marker != target_marker {
-                            let marker_pos = list_item.marker_column;
-                            if marker_pos < line.len() {
-                                let mut new_line = String::new();
-                                new_line.push_str(&line[..marker_pos]);
-                                new_line.push(target_marker);
-                                new_line.push_str(&line[marker_pos + 1..]);
-                                lines[line_idx] = new_line;
-                            }
+                    // Replace the marker if needed
+                    if marker != target_marker {
+                        let marker_pos = list_item.marker_column;
+                        if marker_pos < line.len() {
+                            let mut new_line = String::new();
+                            new_line.push_str(&line[..marker_pos]);
+                            new_line.push(target_marker);
+                            new_line.push_str(&line[marker_pos + 1..]);
+                            lines[line_idx] = new_line;
                         }
                     }
                 }
@@ -387,7 +379,7 @@ mod tests {
     fn test_consistent_asterisk_style() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
         let content = "* Item 1\n* Item 2\n  * Nested\n* Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -396,7 +388,7 @@ mod tests {
     fn test_consistent_dash_style() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
         let content = "- Item 1\n- Item 2\n  - Nested\n- Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -405,7 +397,7 @@ mod tests {
     fn test_consistent_plus_style() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
         let content = "+ Item 1\n+ Item 2\n  + Nested\n+ Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -414,7 +406,7 @@ mod tests {
     fn test_inconsistent_style() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
         let content = "* Item 1\n- Item 2\n+ Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert_eq!(result[0].line, 2);
@@ -425,7 +417,7 @@ mod tests {
     fn test_asterisk_style_enforced() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let content = "* Item 1\n- Item 2\n+ Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert_eq!(result[0].message, "List marker '-' does not match expected style '*'");
@@ -436,7 +428,7 @@ mod tests {
     fn test_dash_style_enforced() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Dash);
         let content = "* Item 1\n- Item 2\n+ Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert_eq!(result[0].message, "List marker '*' does not match expected style '-'");
@@ -447,7 +439,7 @@ mod tests {
     fn test_plus_style_enforced() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Plus);
         let content = "* Item 1\n- Item 2\n+ Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert_eq!(result[0].message, "List marker '*' does not match expected style '+'");
@@ -458,7 +450,7 @@ mod tests {
     fn test_fix_consistent_style() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
         let content = "* Item 1\n- Item 2\n+ Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "* Item 1\n* Item 2\n* Item 3");
     }
@@ -467,7 +459,7 @@ mod tests {
     fn test_fix_asterisk_style() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let content = "- Item 1\n+ Item 2\n- Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "* Item 1\n* Item 2\n* Item 3");
     }
@@ -476,7 +468,7 @@ mod tests {
     fn test_fix_dash_style() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Dash);
         let content = "* Item 1\n+ Item 2\n* Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "- Item 1\n- Item 2\n- Item 3");
     }
@@ -485,7 +477,7 @@ mod tests {
     fn test_fix_plus_style() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Plus);
         let content = "* Item 1\n- Item 2\n* Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "+ Item 1\n+ Item 2\n+ Item 3");
     }
@@ -494,7 +486,7 @@ mod tests {
     fn test_nested_lists() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
         let content = "* Item 1\n  * Nested 1\n    * Double nested\n  - Wrong marker\n* Item 2";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 4);
@@ -504,7 +496,7 @@ mod tests {
     fn test_fix_nested_lists() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
         let content = "* Item 1\n  - Nested 1\n    + Double nested\n  - Nested 2\n* Item 2";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(
             fixed,
@@ -516,7 +508,7 @@ mod tests {
     fn test_with_code_blocks() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let content = "* Item 1\n\n```\n- This is in code\n+ Not a list\n```\n\n- Item 2";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 8);
@@ -526,7 +518,7 @@ mod tests {
     fn test_with_blockquotes() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
         let content = "> * Item 1\n> - Item 2\n\n* Regular item\n+ Different marker";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Should detect inconsistencies both in blockquote and regular content
         assert!(result.len() >= 2);
@@ -536,7 +528,7 @@ mod tests {
     fn test_empty_document() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let content = "";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -545,7 +537,7 @@ mod tests {
     fn test_no_lists() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let content = "This is a paragraph.\n\nAnother paragraph.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -554,7 +546,7 @@ mod tests {
     fn test_ordered_lists_ignored() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let content = "1. Item 1\n2. Item 2\n   1. Nested\n3. Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -563,7 +555,7 @@ mod tests {
     fn test_mixed_ordered_unordered() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let content = "1. Ordered\n   * Unordered nested\n   - Wrong marker\n2. Another ordered";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 3);
@@ -573,7 +565,7 @@ mod tests {
     fn test_fix_preserves_content() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Dash);
         let content = "* Item with **bold** and *italic*\n+ Item with `code`\n* Item with [link](url)";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(
             fixed,
@@ -585,7 +577,7 @@ mod tests {
     fn test_fix_preserves_indentation() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let content = "  - Indented item\n    + Nested item\n  - Another indented";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "  * Indented item\n    * Nested item\n  * Another indented");
     }
@@ -594,7 +586,7 @@ mod tests {
     fn test_multiple_spaces_after_marker() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
         let content = "*   Item 1\n-   Item 2\n+   Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         let fixed = rule.fix(&ctx).unwrap();
@@ -605,7 +597,7 @@ mod tests {
     fn test_tab_after_marker() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
         let content = "*\tItem 1\n-\tItem 2";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         let fixed = rule.fix(&ctx).unwrap();
@@ -615,12 +607,13 @@ mod tests {
     #[test]
     fn test_edge_case_marker_at_end() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
-        let content = "*\n-\n+";
-        let ctx = LintContext::new(content);
+        // These are valid list items with minimal content (just a space)
+        let content = "* \n- \n+ ";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 2);
+        assert_eq!(result.len(), 2); // Should flag - and + as wrong markers
         let fixed = rule.fix(&ctx).unwrap();
-        assert_eq!(fixed, "*\n*\n*");
+        assert_eq!(fixed, "* \n* \n* ");
     }
 
     #[test]
@@ -634,7 +627,7 @@ mod tests {
 
         let rule = MD004UnorderedListStyle::from_config(&config);
         let content = "* Item 1\n- Item 2";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
     }
@@ -658,7 +651,7 @@ mod tests {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Sublist);
         // Level 0 should use *, level 1 should use +, level 2 should use -
         let content = "* Item 1\n  + Item 2\n    - Item 3\n      * Item 4\n  + Item 5";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Sublist style should accept cycling markers");
     }
@@ -668,7 +661,7 @@ mod tests {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Sublist);
         // Wrong markers for each level
         let content = "- Item 1\n  * Item 2\n    + Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 3);
         assert_eq!(
@@ -689,7 +682,7 @@ mod tests {
     fn test_fix_sublist_style() {
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Sublist);
         let content = "- Item 1\n  - Item 2\n    - Item 3\n      - Item 4";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "* Item 1\n  + Item 2\n    - Item 3\n      * Item 4");
     }
@@ -711,7 +704,7 @@ mod tests {
                 i
             ));
         }
-        let ctx = LintContext::new(&content);
+        let ctx = LintContext::new(&content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Should detect all non-asterisk markers
         assert!(result.len() > 600);
