@@ -160,11 +160,11 @@ impl Rule for MD056TableColumnCount {
         for (i, line) in lines.iter().enumerate() {
             let warning_idx = warnings.iter().position(|w| w.line == i + 1);
 
-            if let Some(idx) = warning_idx {
-                if let Some(fix) = &warnings[idx].fix {
-                    result.push(fix.replacement.clone());
-                    continue;
-                }
+            if let Some(idx) = warning_idx
+                && let Some(fix) = &warnings[idx].fix
+            {
+                result.push(fix.replacement.clone());
+                continue;
             }
             result.push(line.to_string());
         }
@@ -201,7 +201,7 @@ mod tests {
 |----------|----------|----------|
 | Cell 1   | Cell 2   | Cell 3   |
 | Cell 4   | Cell 5   | Cell 6   |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -214,7 +214,7 @@ mod tests {
 |----------|----------|----------|
 | Cell 1   | Cell 2   |
 | Cell 4   | Cell 5   | Cell 6   |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -229,7 +229,7 @@ mod tests {
 |----------|----------|
 | Cell 1   | Cell 2   | Cell 3   | Cell 4   |
 | Cell 5   | Cell 6   |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -243,7 +243,7 @@ mod tests {
         let content = "| Header 1 | Header 2 | Header 3 |
 |----------|----------|
 | Cell 1   | Cell 2   | Cell 3   |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -258,7 +258,7 @@ mod tests {
 |----------|----------|----------|
 | Cell 1   | Cell 2   |
 | Cell 4   | Cell 5   | Cell 6   |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert!(fixed.contains("| Cell 1 | Cell 2 |  |"));
@@ -271,7 +271,7 @@ mod tests {
 |----------|----------|
 | Cell 1   | Cell 2   | Cell 3   | Cell 4   |
 | Cell 5   | Cell 6   |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert!(fixed.contains("| Cell 1 | Cell 2 |"));
@@ -286,7 +286,7 @@ mod tests {
 ---------|----------|----------|
 Cell 1   | Cell 2   |
 Cell 4   | Cell 5   | Cell 6   |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -298,9 +298,9 @@ Cell 4   | Cell 5   | Cell 6   |";
         let rule = MD056TableColumnCount;
         let content = "| Header 1 | Header 2 | Header 3
 |----------|----------|----------
-| Cell 1   | Cell 2   
+| Cell 1   | Cell 2
 | Cell 4   | Cell 5   | Cell 6";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -313,7 +313,7 @@ Cell 4   | Cell 5   | Cell 6   |";
         let content = "This is not a table
 Just regular text
 No pipes here";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -326,7 +326,7 @@ No pipes here";
 |----------|----------|----------|
 |          |          |          |
 | Cell 1   |          | Cell 3   |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -345,7 +345,7 @@ Some text in between.
 |----------------|----------------|----------------|
 | Data 3         | Data 4         |
 | Data 5         | Data 6         | Data 7         |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -361,7 +361,7 @@ Some text in between.
 |---------|-------------|
 | `echo \\| grep` | Pipe example |
 | `ls` | List files |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should handle escaped pipes correctly
@@ -372,7 +372,7 @@ Some text in between.
     fn test_empty_content() {
         let rule = MD056TableColumnCount;
         let content = "";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -390,7 +390,7 @@ Some text in between.
 | Real | Table |
 |------|-------|
 | Data | Here  |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should not check tables inside code blocks
@@ -404,7 +404,7 @@ Some text in between.
         let content = "| Header 1 | Header 2 | Header 3
 |----------|----------|----------
 | Cell 1   | Cell 2";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         let lines: Vec<&str> = fixed.lines().collect();
@@ -420,7 +420,7 @@ Some text in between.
 |---------|
 | Cell 1  |
 | Cell 2  |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -433,7 +433,7 @@ Some text in between.
 |:-----|:------:|------:|
 | L    | C      | R     |
 | Left | Center |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -447,7 +447,7 @@ Some text in between.
 |------|------|------|
 | 田中 | 25   | 東京 |
 | 佐藤 | 30   |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -460,7 +460,7 @@ Some text in between.
         let content = "| Short | Very very very very very very very very very very long header | Another |
 |-------|--------------------------------------------------------------|---------|
 | Data  | This is an extremely long cell content that goes on and on   |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -474,7 +474,7 @@ Some text in between.
 |---|---|---|
 | 1 | 2 |
 ";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert!(fixed.ends_with('\n'));
@@ -487,7 +487,7 @@ Some text in between.
         let content = "| A | B | C |
 |---|---|---|
 | 1 | 2 |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert!(!fixed.ends_with('\n'));
