@@ -195,19 +195,6 @@ impl MD057ExistingRelativeLinks {
             }
         }
     }
-
-    /// Extract a URL from a Markdown link segment
-    #[allow(dead_code)]
-    fn extract_url_from_link<'a>(&self, link_text: &'a str) -> Option<(&'a str, usize)> {
-        // Find the URL part using regex
-        URL_EXTRACT_REGEX.captures(link_text).and_then(move |caps| {
-            caps.get(1).map(|url_match| {
-                let url = url_match.as_str().trim();
-                let position = url_match.start();
-                (url, position)
-            })
-        })
-    }
 }
 
 impl Rule for MD057ExistingRelativeLinks {
@@ -334,16 +321,16 @@ impl Rule for MD057ExistingRelativeLinks {
                     }
 
                     // Find the URL part after the link text
-                    if let Some(caps) = URL_EXTRACT_REGEX.captures_at(line, end_pos - 1) {
-                        if let Some(url_group) = caps.get(1) {
-                            let url = url_group.as_str().trim();
+                    if let Some(caps) = URL_EXTRACT_REGEX.captures_at(line, end_pos - 1)
+                        && let Some(url_group) = caps.get(1)
+                    {
+                        let url = url_group.as_str().trim();
 
-                            // Calculate column position
-                            let column = start_pos + 1;
+                        // Calculate column position
+                        let column = start_pos + 1;
 
-                            // Process and validate the link
-                            self.process_link(url, link.line, column, &mut warnings);
-                        }
+                        // Process and validate the link
+                        self.process_link(url, link.line, column, &mut warnings);
                     }
                 }
             }
@@ -473,7 +460,7 @@ mod tests {
         let rule = MD057ExistingRelativeLinks::new();
         let content = "[Link](missing.md)";
 
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Should have no warnings without base path");
     }
@@ -505,7 +492,7 @@ mod tests {
         let rule = MD057ExistingRelativeLinks::new().with_path(base_path);
 
         // Test the rule
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should have one warning for the missing.md link but not for the media file
@@ -543,7 +530,7 @@ mod tests {
         // Test with default settings
         let rule = MD057ExistingRelativeLinks::new().with_path(base_path);
 
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should have one warning for missing.md
@@ -573,7 +560,7 @@ mod tests {
         // Test with skip_media_files = true (default)
         let rule_skip_media = MD057ExistingRelativeLinks::new().with_path(base_path);
 
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result_skip = rule_skip_media.check(&ctx).unwrap();
 
         // Should have no warnings when media files are skipped
@@ -588,7 +575,7 @@ mod tests {
             .with_path(base_path)
             .with_skip_media_files(false);
 
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result_all = rule_check_all.check(&ctx).unwrap();
 
         // Should warn about the missing media file
@@ -617,7 +604,7 @@ mod tests {
         let content = "This is a [link](nonexistent.md) and `[not a link](not-checked.md)` in code.";
         let structure = DocumentStructure::new(content);
 
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check_with_structure(&ctx, &structure).unwrap();
 
         // Should only find the real link, not the one in code
@@ -647,7 +634,7 @@ Some more text with `inline code [Link](yet-another-missing.md) embedded`.
         let rule = MD057ExistingRelativeLinks::new().with_path(base_path);
 
         // Test the rule
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should only have warning for the normal link, not for links in code spans
