@@ -1,6 +1,6 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::MD038NoSpaceInCode;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::MD038NoSpaceInCode;
 
 #[test]
 fn test_md038_nested_backticks_not_flagged() {
@@ -15,7 +15,7 @@ fn test_md038_nested_backticks_not_flagged() {
     ];
 
     for case in test_cases {
-        let ctx = LintContext::new(case);
+        let ctx = LintContext::new(case, rumdl_lib::config::MarkdownFlavor::Standard);
         let warnings = rule.check(&ctx).unwrap();
         assert_eq!(
             warnings.len(),
@@ -37,7 +37,7 @@ fn test_md038_still_detects_regular_spaces() {
     ];
 
     for case in cases_with_warnings {
-        let ctx = LintContext::new(case);
+        let ctx = LintContext::new(case, rumdl_lib::config::MarkdownFlavor::Standard);
         let warnings = rule.check(&ctx).unwrap();
         assert!(!warnings.is_empty(), "Should detect spaces in: {case}");
     }
@@ -54,7 +54,7 @@ fn test_md038_lenient_mode_allows_nested_backticks() {
     ];
 
     for case in test_cases {
-        let ctx = LintContext::new(case);
+        let ctx = LintContext::new(case, rumdl_lib::config::MarkdownFlavor::Standard);
         let warnings = rule.check(&ctx).unwrap();
         assert_eq!(
             warnings.len(),
@@ -71,7 +71,7 @@ fn test_md038_documentation_example() {
 
     // This example shows why we don't fix spaces when backticks are nested
     let content = "To show a backtick in code, use `` ` `` or ``` `` ```";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let warnings = rule.check(&ctx).unwrap();
 
     assert_eq!(warnings.len(), 0, "Nested backtick examples should not be flagged");
