@@ -4,19 +4,19 @@
 //! the fix replacement text to the warning range (not the fix range).
 //! This helps catch bugs where warning ranges and fix ranges are mismatched.
 
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::code_block_utils::CodeBlockStyle;
-use rumdl::rules::code_fence_utils::CodeFenceStyle;
-use rumdl::rules::strong_style::StrongStyle;
-use rumdl::rules::*;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::code_block_utils::CodeBlockStyle;
+use rumdl_lib::rules::code_fence_utils::CodeFenceStyle;
+use rumdl_lib::rules::strong_style::StrongStyle;
+use rumdl_lib::rules::*;
 
 /// Simulates how VS Code extension applies a fix by:
 /// 1. Getting the warning range from the rule
 /// 2. Applying the fix replacement text to that warning range only
 /// 3. Returning the result
 fn simulate_vscode_fix(content: &str, rule: &dyn Rule) -> Result<String, String> {
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let warnings = rule.check(&ctx).map_err(|e| format!("Check failed: {e:?}"))?;
 
     if warnings.is_empty() {
@@ -80,7 +80,7 @@ fn create_test_case_for_rule(rule_name: &str) -> Option<(&'static str, Box<dyn R
         )),
         "MD005" => Some((
             "* Item 1\n   * Item with 3 spaces (should be 2)",
-            Box::new(MD005ListIndent),
+            Box::new(MD005ListIndent::default()),
         )),
         "MD006" => Some((
             "  * Indented list item that should trigger MD006",
@@ -141,7 +141,7 @@ fn create_test_case_for_rule(rule_name: &str) -> Option<(&'static str, Box<dyn R
         "MD039" => Some(("[link text ]( url )", Box::new(MD039NoSpaceInLinks))),
         "MD040" => Some(("```\ncode without language\n```", Box::new(MD040FencedCodeLanguage))),
         "MD041" => Some(("Not a heading", Box::new(MD041FirstLineHeading::default()))),
-        "MD042" => Some(("[]()", Box::new(MD042NoEmptyLinks))),
+        "MD042" => Some(("[]()", Box::new(MD042NoEmptyLinks::new()))),
         "MD043" => Some((
             "# Wrong heading",
             Box::new(MD043RequiredHeadings::new(vec!["Introduction".to_string()])),
@@ -165,8 +165,8 @@ fn create_test_case_for_rule(rule_name: &str) -> Option<(&'static str, Box<dyn R
             "Text __strong__ text",
             Box::new(MD050StrongStyle::new(StrongStyle::Underscore)),
         )),
-        "MD051" => Some(("[link](#nonexistent)", Box::new(MD051LinkFragments))),
-        "MD052" => Some(("[ref link][ref]", Box::new(MD052ReferenceLinkImages))),
+        "MD051" => Some(("[link](#nonexistent)", Box::new(MD051LinkFragments::new()))),
+        "MD052" => Some(("[ref link][ref]", Box::new(MD052ReferenceLinkImages::new()))),
         "MD053" => Some((
             "[ref]: https://example.com",
             Box::new(MD053LinkImageReferenceDefinitions::default()),
@@ -303,7 +303,7 @@ mod tests {
 
     #[test]
     fn test_md005_vscode_fix_no_duplication() {
-        let rule = MD005ListIndent;
+        let rule = MD005ListIndent::default();
         let content = "* Item 1\n   * Item with 3 spaces (should be 2)\n* Item 3";
 
         let result = simulate_vscode_fix(content, &rule);
